==> tinyerp-client_3.3.0.orig.tar.gz: tinyerp-client-3.3.0/bin/widget/view/form_gtk/selection.py <==
##############################################################################
#
# Copyright (c) 2004-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
#
# $Id: selection.py 3210 2006-05-18 16:04:48Z ged $
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsability of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# garantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################

import common
import interface
import gtk
import gobject
from gtk import glade


# Can be improved !!!

class selection(interface.widget_interface):
	def __init__(self, window, parent, model, attrs={}):
		interface.widget_interface.__init__(self, window, parent, model, attrs)

		win_gl = glade.XML(common.terp_path("terp.glade"),"widget_combobox")
		self.widget = win_gl.get_widget('widget_combobox')

		#self.widget = gtk.combo_box_entry_new_text()
		self.widget.child.connect('changed', self.sig_changed)
		self.widget.child.set_editable(False)
		self.widget.child.connect('button_press_event', self._menu_open)
		#self.widget.set_has_frame(False)

		self.ok = True
		self._selection={}
		self.set_popdown(attrs.get('selection',[]))

	def set_popdown(self, selection):
		model = gtk.ListStore(gobject.TYPE_STRING)
		self._selection={}
		lst = []
		for (i,j) in selection:
			name = str(j)
			lst.append(name)
			self._selection[name]=i
		for l in lst:
			i = model.append()
			model.set(i, 0, l)
		self.widget.set_model(model)
		self.widget.set_text_column(0)
		return lst

	def _readonly_set(self, value):
		interface.widget_interface._readonly_set(self, value)
		self.widget.set_sensitive(not value)

	def set_value(self, model_field):
		res = self.widget.child.get_text()
		model_field.set_client(self._selection.get(res, False))

	def _menu_sig_default_set(self):
		self.set_value(self._view.modelfield)
		super(selection, self)._menu_sig_default_set()

	def display(self, model_field):
		self.ok = False
		if not model_field:
			self.widget.child.set_text('')
			self.ok = True
			return False
		super(selection, self).display(model_field)
		value = model_field.get()
		if not value:
			self.widget.child.set_text('')
		else:
			found = False
			for long_text, sel_value in self._selection.items():
				if sel_value == value:
					self.widget.child.set_text(long_text)
					found = True
					break
			if not found:
				common.warning(_('The selection box for "%s" is using a undefined value !') % self.attrs['string'])
		self.ok = True

	def sig_changed(self, *args):
		if self.ok:
			self._focus_out()
		if self.attrs.get('on_change',False) and self.value:
			if self.ok:
				self.on_change(self.attrs['on_change'])

	def _color_widget(self):
		return self.widget.child

==> tinyerp-client_3.4.2.orig.tar.gz: tinyerp-client-3.4.2/bin/widget/view/form_gtk/selection.py <==
##############################################################################
#
# Copyright (c) 2004-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
#
# $Id: selection.py 3946 2006-08-28 23:23:03Z pinky $
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsability of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# garantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################

import common
import interface
import gtk
import gobject
from gtk import glade


# Can be improved !!!

class selection(interface.widget_interface):
	def __init__(self, window, parent, model, attrs={}):
		interface.widget_interface.__init__(self, window, parent, model, attrs)

		win_gl = glade.XML(common.terp_path("terp.glade"),"widget_combobox")
		self.widget = win_gl.get_widget('widget_combobox')

		#self.widget = gtk.combo_box_entry_new_text()
		self.widget.child.connect('changed', self.sig_changed)
		self.widget.child.set_editable(False)
		self.widget.child.connect('button_press_event', self._menu_open)
		#self.widget.set_has_frame(False)

		self.ok = True
		self._selection={}
		self.set_popdown(attrs.get('selection',[]))

	def set_popdown(self, selection):
		model = gtk.ListStore(gobject.TYPE_STRING)
		self._selection={}
		lst = []
		for (i,j) in selection:
			name = str(j)
			lst.append(name)
			self._selection[name]=i
		for l in lst:
			i = model.append()
			model.set(i, 0, l)
		self.widget.set_model(model)
		self.widget.set_text_column(0)
		return lst

	def _readonly_set(self, value):
		interface.widget_interface._readonly_set(self, value)
		self.widget.set_sensitive(not value)

	def value_get(self):
		res = self.widget.child.get_text()
		return self._selection.get(res, False)

	def set_value(self, model_field):
		model_field.set_client(self.value_get())

	def _menu_sig_default_set(self):
		self.set_value(self._view.modelfield)
		super(selection, self)._menu_sig_default_set()

	def display(self, model_field):
		self.ok = False
		if not model_field:
			self.widget.child.set_text('')
			self.ok = True
			return False
		super(selection, self).display(model_field)
		value = model_field.get()
		if not value:
			self.widget.child.set_text('')
		else:
			found = False
			for long_text, sel_value in self._selection.items():
				if sel_value == value:
					self.widget.child.set_text(long_text)
					found = True
					break
		self.ok = True

	def sig_changed(self, *args):
		if self.ok:
			self._focus_out()
		#if self.attrs.get('on_change',False) and self.value_get():
		#	if self.ok:
		#		self.attrson_change(self.attrs['on_change'])

	def _color_widget(self):
		return self.widget.child
